def now():
    print("This is how you win!")
def girl():
    print("Now you really lost!")
def hi():
    print("Wow this is a good guy!")
def tryout():
    print("This ain't gonna work anymore")
name = 10
lol = 'winner,winner,chicken,dinner'
god  = "Whoever you wish"
woah = "I didn't fix this!"